CustomerRegisterResponse class
Constructors
- CustomerRegisterResponse(int? id, String? email, dynamic auth_token)
- CustomerRegisterResponse.empty()
-
factory
-
CustomerRegisterResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auth_token → dynamic
-
final
- email → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? id, String? email, dynamic auth_token}) → CustomerRegisterResponse -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited